@@ -13,11 +13,14 @@ def get_allowed_predicate(allowed=None):
             return True
         allowed = allowed
     return allowed
-def get_globs(items):
+def get_globs(items,recursive: bool = True,allowed=None):
     glob_paths = []
     for item in make_list(items):
         pattern = os.path.join(item, "**/*")  # include all files recursively\n
-        glob_paths += glob.glob(pattern, recursive=True)
+        nuItems = glob.glob(pattern, recursive=recursive)
+        if allowed:
+            nuItems = [nuItem for nuItem in nuItems if nuItem and allowed(nuItem)]
+        glob_paths += nuItems
     return glob_paths
 def get_allowed_files(items,allowed=True):
     allowed = get_allowed_predicate(allowed=allowed)
@@ -49,7 +52,39 @@ def get_all_allowed_dirs(items,allowed=None):
     for directory in dirs:
         nu_dirs += get_filtered_dirs(directory,allowed=allowed,dirs=nu_dirs)
     return nu_dirs
-
+def get_files_and_dirs(
+    directory: str,
+    cfg: Optional["ScanConfig"] = None,
+    allowed_exts: Optional[Set[str]] = False,
+    unallowed_exts: Optional[Set[str]] = False,
+    exclude_types: Optional[Set[str]] = False,
+    exclude_dirs: Optional[List[str]] = False,
+    exclude_patterns: Optional[List[str]] = False,
+    add = False,
+    recursive: bool = True,
+    include_files: bool = True
+    ):
+    cfg = cfg or define_defaults(
+        allowed_exts=allowed_exts,
+        unallowed_exts=unallowed_exts,
+        exclude_types=exclude_types,
+        exclude_dirs=exclude_dirs,
+        exclude_patterns=exclude_patterns,
+        add=add
+        )
+    allowed = make_allowed_predicate(cfg)
+    items=[]
+    files =[]
+    if recursive:
+        items = get_globs(directory,recursive=recursive,allowed=allowed)
+    else:
+        directories = make_list(directory)
+        for directory in directories:
+            items +=[os.path.join(directory,item) for item in os.listdir(directory)]
+    dirs = get_allowed_dirs(items,allowed=allowed)
+    if include_files:
+        files = get_allowed_files(items,allowed=allowed)
+    return dirs,files
 def make_allowed_predicate(cfg: ScanConfig) -> Callable[[str], bool]:
     def allowed(path: str) -> bool:
         p = Path(path)
