@@ -73,8 +73,14 @@ def ensure_patterns(patterns):
             else:
                 pattern = f"{pattern}*"
         patterns[i] = pattern
-
     return patterns
+def ensure_dirtypes(obj):
+    if obj in [True,None,False]:
+        return obj
+    if isinstance(obj,str):
+        obj = obj.split(',')
+    obj = make_list(obj)
+    return obj
 def define_defaults(
     allowed_exts: Optional[Set[str]] = False,
     unallowed_exts: Optional[Set[str]] = False,
@@ -85,6 +91,8 @@ def define_defaults(
     ):
     allowed_exts=ensure_exts(allowed_exts)
     unallowed_exts=ensure_exts(unallowed_exts)
+    exclude_types = ensure_dirtypes(exclude_types)
+    exclude_dirs = ensure_dirtypes(exclude_dirs)
     exclude_patterns = ensure_patterns(exclude_patterns)
     DEFAULT_CFG = ScanConfig(
         allowed_exts = get_default_modular(allowed_exts,default=DEFAULT_ALLOWED_EXTS,add=add,typ=set),
